User prompt
daire çok az aşağıya insin
User prompt
arkaplanı en arkaya atalım
User prompt
arkaplanı ekleyelim
User prompt
tebrikler yazısı yazdıktan 2 saniye sonra kaybolsun ↪💡 Consider importing and using the following plugins: @upit/tween.v1
User prompt
skor her 100 arttığında tebrikler yazısı gelsin
User prompt
+1 birazdaha aşağıda yazsın
User prompt
+1 biraz daha aşağıda gelsin
User prompt
skorun biraz altında küçük bir +1 yazısı her tıklanılsığında gelsin
User prompt
skora 1 eklensin her tıklanışta
User prompt
"imlecde nereye tıklandıysa +1 yazı oraya gelsin" sil
User prompt
imlecde nereye tıklandıysa +1 yazısı oraya gelsin
User prompt
her tıklandığında +1 yazısı gelsin
User prompt
+1 yzısı dairenin içinde nereye tıklandıysa orada görünsünü sil
User prompt
+1 yazısı dairenin içinde nereye tıklandıysa orada gözüksün
User prompt
+1 yazısı dairenin içinde görülsün
User prompt
her tıklamada küçük +1 yazsın
User prompt
her tıklamada T sesi çıksın
User prompt
her daireye tıklandığında t sesi gelsin
Initial prompt
click
===================================================================
--- original.js
+++ change.js
@@ -1,42 +1,44 @@
-/****
+/****
* Classes
-****/
+****/
//<Assets used in the game will automatically appear here>
//<Write imports for supported plugins here>
//<Write entity 'classes' with empty functions for important behavior here>
var ClickableCircle = Container.expand(function () {
- var self = Container.call(this);
- var circleGraphics = self.attachAsset('circle', {
- anchorX: 0.5,
- anchorY: 0.5
- });
- self.down = function (x, y, obj) {
- // Increase score on click
- LK.setScore(LK.getScore() + 1);
- scoreTxt.setText(LK.getScore());
- };
+ var self = Container.call(this);
+ var circleGraphics = self.attachAsset('circle', {
+ anchorX: 0.5,
+ anchorY: 0.5
+ });
+ self.down = function (x, y, obj) {
+ // Increase score on click
+ LK.setScore(LK.getScore() + 1);
+ scoreTxt.setText(LK.getScore());
+ // Play sound 't' when clicked
+ LK.getSound('t').play();
+ };
});
-/****
+/****
* Initialize Game
-****/
+****/
var game = new LK.Game({
- backgroundColor: 0x000000 //Init game with black background
+ backgroundColor: 0x000000 //Init game with black background
});
-/****
+/****
* Game Code
-****/
+****/
//<Write game logic code here, including initializing arrays and variables>
var scoreTxt = new Text2('0', {
- size: 150,
- fill: 0xFFFFFF
+ size: 150,
+ fill: 0xFFFFFF
});
scoreTxt.anchor.set(0.5, 0);
LK.gui.top.addChild(scoreTxt);
var circle = game.addChild(new ClickableCircle());
circle.x = 2048 / 2;
circle.y = 2732 / 2;
game.update = function () {
- // Game logic updates
+ // Game logic updates
};
\ No newline at end of file